@@ -5,8 +5,6 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 1995, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
- *
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -53,13 +51,7 @@
 # define  _(s) gettext (s)
 # define N_(s) gettext_noop (s)
 #else
-# ifdef WIN32
-#  define  _(s) T_(s)
-#  undef  ngettext
-#  define  ngettext(s,p,n) T_(p)
-# else
-#  define  _(s) (s)
-# endif
+# define  _(s) (s)
 # define N_(s)  s
 #endif
 
@@ -95,8 +87,7 @@ static int scores[MAX_VAR], textEnd[MAX_VAR], curDepth[2], nrVariations[2];
 
 extern int initialRulePlies;
 
-void
-MakeEngineOutputTitle ()
+void MakeEngineOutputTitle()
 {
 	static char buf[MSG_SIZ];
 	static char oldTitle[MSG_SIZ];
@@ -111,19 +102,17 @@ MakeEngineOutputTitle ()
 	while( (signed char)boards[count][EP_STATUS] <= EP_NONE && count > backwardMostMove ) count--;
 	if( count == backwardMostMove ) count -= initialRulePlies;
 	count = currentMove - count;
+	snprintf(buf, MSG_SIZ, "%s (%d reversible plies)", title, count);
 	if(!rule) rule = 100;
-	if(count >= rule - 40 && (!appData.icsActive || gameMode == IcsObserving)) {
-		snprintf(buf, MSG_SIZ, ngettext("%s (%d reversible ply)", "%s (%d reversible plies)", count), title, count);
-		safeStrCpy(title, buf, MSG_SIZ);
-	}
+	if(count >= rule - 40 && (!appData.icsActive || gameMode == IcsObserving)) 
+	  safeStrCpy(title, buf, MSG_SIZ);
 	if(!strcmp(oldTitle, title)) return;
 	safeStrCpy(oldTitle, title, MSG_SIZ);
 	SetEngineOutputTitle(title);
 }
 
 // back end, due to front-end wrapper for SetWindowText, and new SetIcon arguments
-void
-SetEngineState (int which, int state, char * state_data)
+void SetEngineState( int which, int state, char * state_data )
 {
     int x_which = 1 - which;
 
@@ -155,8 +144,7 @@ SetEngineState (int which, int state, char * state_data)
 }
 
 // back end, now the front-end wrapper ClearMemo is used, and ed no longer contains handles.
-void
-SetProgramStats (FrontEndProgramStats * stats) // now directly called by back-end
+void SetProgramStats( FrontEndProgramStats * stats ) // now directly called by back-end
 {
     EngineOutputData ed;
     int clearMemo = FALSE;
@@ -243,8 +231,7 @@ SetProgramStats (FrontEndProgramStats * stats) // now directly called by back-en
 #define ENGINE_COLOR_UNKNOWN    ' '
 
 // pure back end
-static char
-GetEngineColor (int which)
+static char GetEngineColor( int which )
 {
     char result = ENGINE_COLOR_UNKNOWN;
 
@@ -277,8 +264,7 @@ GetEngineColor (int which)
 }
 
 // pure back end
-static char
-GetActiveEngineColor ()
+static char GetActiveEngineColor()
 {
     char result = ENGINE_COLOR_UNKNOWN;
 
@@ -290,8 +276,7 @@ GetActiveEngineColor ()
 }
 
 // pure back end
-static int
-IsEnginePondering (int which)
+static int IsEnginePondering( int which )
 {
     int result = FALSE;
 
@@ -316,8 +301,7 @@ IsEnginePondering (int which)
 }
 
 // back end
-static void
-SetDisplayMode (int mode)
+static void SetDisplayMode( int mode )
 {
     if( windowMode != mode ) {
         windowMode = mode;
@@ -327,8 +311,7 @@ SetDisplayMode (int mode)
 }
 
 // pure back end
-static void
-VerifyDisplayMode ()
+static void VerifyDisplayMode()
 {
     int mode;
 
@@ -358,8 +341,7 @@ VerifyDisplayMode ()
 }
 
 // back end. Determine what icon to set in the color-icon field, and print it
-void
-SetEngineColorIcon (int which)
+void SetEngineColorIcon( int which )
 {
     char color = GetEngineColor(which);
     int nicon = 0;
@@ -378,8 +360,7 @@ SetEngineColorIcon (int which)
 
 // [HGM] multivar: sort Thinking Output within one depth on score
 
-static int
-InsertionPoint (int len, EngineOutputData *ed)
+static int InsertionPoint( int len, EngineOutputData * ed )
 {
 	int i, offs = 0, newScore = ed->score, n = ed->which;
 
@@ -411,8 +392,7 @@ InsertionPoint (int len, EngineOutputData *ed)
 
 
 // pure back end, now SetWindowText is called via wrapper DoSetWindowText
-static void
-UpdateControls (EngineOutputData *ed)
+static void UpdateControls( EngineOutputData * ed )
 {
 //    int isPondering = FALSE;
 
@@ -553,8 +533,7 @@ UpdateControls (EngineOutputData *ed)
 }
 
 // [HGM] kibitz: write kibitz line; split window for it if necessary
-void
-OutputKibitz (int window, char *text)
+void OutputKibitz(int window, char *text)
 {
 	static int currentLineEnd[2];
 	int where = 0;
