@@ -54,9 +54,24 @@
 #define ICS_LOGON    ".icsrc"
 #define INFOFILE     "xboard.info"
 #define MANPAGE      "xboard.6"
+#if ENABLE_NLS
+#define CLOCK_FONT_NAME \
+  "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*," \
+  "-misc-fixed-bold-r-normal--*-*-*-*-*-*-*-*," \
+  "-*-*-*-*-*-*-*-*-*-*-*-*-*-*"
+#define COORD_FONT_NAME \
+  "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*," \
+  "-misc-fixed-bold-r-normal--*-*-*-*-*-*-*-*," \
+  "-*-*-*-*-*-*-*-*-*-*-*-*-*-*"
+#define DEFAULT_FONT_NAME \
+  "-*-helvetica-medium-r-normal--*-*-*-*-*-*-*-*," \
+  "-misc-fixed-medium-r-normal--*-*-*-*-*-*-*-*," \
+  "-*-*-*-*-*-*-*-*-*-*-*-*-*-*"
+#else
 #define CLOCK_FONT_NAME         "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
 #define COORD_FONT_NAME         "-*-helvetica-bold-r-normal--*-*-*-*-*-*-*-*"
 #define DEFAULT_FONT_NAME       "-*-helvetica-medium-r-normal--*-*-*-*-*-*-*-*"
+#endif
 #define COLOR_SHOUT             "green"
 #define COLOR_SSHOUT            "green,black,1"
 #define COLOR_CHANNEL1          "cyan"
@@ -119,6 +134,13 @@ typedef struct {
 typedef int (*FileProc) P((FILE *f, int n, char *title));
 
 int PopDown P((int n));
+void NewTagsPopup P((char *text, char *msg));
+int AppendText P((Option *opt, char *s));
+int GenericPopUp P((Option *option, char *title, int dlgNr));
+void NewCommentPopup P((char *title, char *text, int index));
+void MarkMenu P((char *item, int dlgNr));
+void GetWidgetText P((Option *opt, char **buf));
+void ClearTextWidget P((Option *opt));
 void InputBoxPopup P((void));
 void CatchDeleteWindow(Widget w, String procname);
 void PlaySound P((char *name));
