@@ -1,7 +1,6 @@
 /*
  * New (WinBoard-style) Move history for XBoard
  *
- * Copyright 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -70,29 +69,25 @@ extern Option historyOptions[];
 
 // ------------- low-level front-end actions called by MoveHistory back-end -----------------
 
-void
-HighlightMove (int from, int to, Boolean highlight)
+void HighlightMove( int from, int to, Boolean highlight )
 {
     if(highlight)
 	XawTextSetSelection( historyOptions[0].handle, from, to ); // for lack of a better method, use selection for highighting
 }
 
-void
-ClearHistoryMemo ()
+void ClearHistoryMemo()
 {
     ClearTextWidget(&historyOptions[0]);
 }
 
 // the bold argument says 0 = normal, 1 = bold typeface
 // the colorNr argument says 0 = font-default, 1 = gray
-int
-AppendToHistoryMemo (char * text, int bold, int colorNr)
+int AppendToHistoryMemo( char * text, int bold, int colorNr )
 {
     return AppendText(&historyOptions[0], text); // for now ignore bold & color stuff, as Xaw cannot handle that
 }
 
-void
-ScrollToCurrent (int caretPos)
+void ScrollToCurrent(int caretPos)
 {
     Arg args[10];
     char *s;
@@ -135,20 +130,17 @@ Option historyOptions[] = {
 
 // ------------ standard entry points into MoveHistory code -----------
 
-Boolean
-MoveHistoryIsUp ()
+Boolean MoveHistoryIsUp()
 {
     return shellUp[7];
 }
 
-Boolean
-MoveHistoryDialogExists ()
+Boolean MoveHistoryDialogExists()
 {
     return shells[7] != NULL;
 }
 
-void
-HistoryPopUp ()
+void HistoryPopUp()
 {
     if(GenericPopUp(historyOptions, _("Move list"), 7))
 	XtOverrideTranslations(historyOptions[0].handle, XtParseTranslationTable(historyTranslations));
@@ -156,7 +148,11 @@ HistoryPopUp ()
 }
 
 void
-HistoryShowProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
+HistoryShowProc(w, event, prms, nprms)
+     Widget w;
+     XEvent *event;
+     String *prms;
+     Cardinal *nprms;
 {
   if (!shellUp[7]) {
     ASSIGN(historyText, "");
